@@ -160,34 +160,51 @@ intersphinx_mapping = {
     'pandas': ('https://pandas.pydata.org/pandas-docs/stable/', None),
     'pytest': ('https://pytest.org/en/stable/', None),
     'python': ('https://docs.python.org/3/', None),
-    'scipy': ('https://docs.scipy.org/doc/scipy/reference/', None),
+    'scipy': ('https://docs.scipy.org/doc/scipy/', None),
     'tornado': ('https://www.tornadoweb.org/en/stable/', None),
 }
 
 
 # Sphinx gallery configuration
 
+def matplotlib_reduced_latex_scraper(block, block_vars, gallery_conf,
+                                     **kwargs):
+    """
+    Reduce srcset when creating a PDF.
+
+    Because sphinx-gallery runs *very* early, we cannot modify this even in the
+    earliest builder-inited signal. Thus we do it at scraping time.
+    """
+    from sphinx_gallery.scrapers import matplotlib_scraper
+
+    if gallery_conf['builder_name'] == 'latex':
+        gallery_conf['image_srcset'] = []
+    return matplotlib_scraper(block, block_vars, gallery_conf, **kwargs)
+
+
 sphinx_gallery_conf = {
+    'backreferences_dir': Path('api') / Path('_as_gen'),
+    # Compression is a significant effort that we skip for local and CI builds.
+    'compress_images': ('thumbnails', 'images') if is_release_build else (),
+    'doc_module': ('matplotlib', 'mpl_toolkits'),
     'examples_dirs': ['../examples', '../tutorials', '../plot_types'],
     'filename_pattern': '^((?!sgskip).)*$',
     'gallery_dirs': ['gallery', 'tutorials', 'plot_types'],
-    'doc_module': ('matplotlib', 'mpl_toolkits'),
-    'reference_url': {
-        'matplotlib': None,
-        'numpy': 'https://numpy.org/doc/stable/',
-        'scipy': 'https://docs.scipy.org/doc/scipy/reference/',
-    },
-    'backreferences_dir': Path('api') / Path('_as_gen'),
-    'subsection_order': gallery_order.sectionorder,
-    'within_subsection_order': gallery_order.subsectionorder,
-    'remove_config_comments': True,
-    'min_reported_time': 1,
-    'thumbnail_size': (320, 224),
-    # Compression is a significant effort that we skip for local and CI builds.
-    'compress_images': ('thumbnails', 'images') if is_release_build else (),
-    'matplotlib_animations': True,
+    'image_scrapers': (matplotlib_reduced_latex_scraper, ),
     'image_srcset': ["2x"],
     'junit': '../test-results/sphinx-gallery/junit.xml' if CIRCLECI else '',
+    'matplotlib_animations': True,
+    'min_reported_time': 1,
+    'reference_url': {'matplotlib': None},
+    'remove_config_comments': True,
+    'reset_modules': (
+        'matplotlib',
+        # clear basic_units module to re-register with unit registry on import
+        lambda gallery_conf, fname: sys.modules.pop('basic_units', None)
+    ),
+    'subsection_order': gallery_order.sectionorder,
+    'thumbnail_size': (320, 224),
+    'within_subsection_order': gallery_order.subsectionorder,
 }
 
 mathmpl_fontsize = 11.0
@@ -212,8 +229,8 @@ source_suffix = '.rst'
 # This is the default encoding, but it doesn't hurt to be explicit
 source_encoding = "utf-8"
 
-# The master toctree document.
-master_doc = 'users/index'
+# The toplevel toctree document (renamed to root_doc in Sphinx 4.0)
+root_doc = master_doc = 'users/index'
 
 # General substitutions.
 try:
@@ -321,6 +338,9 @@ html_static_path = ['_static']
 # default is ``".html"``.
 html_file_suffix = '.html'
 
+# this makes this the canonical link for all the pages on the site...
+html_baseurl = 'https://matplotlib.org/stable/'
+
 # If not '', a 'Last updated on:' timestamp is inserted at every page bottom,
 # using the given strftime format.
 html_last_updated_fmt = '%b %d, %Y'
@@ -343,6 +363,10 @@ html_sidebars = {
     # '**': ['localtoc.html', 'pagesource.html']
 }
 
+# Copies only relevant code, not the '>>>' prompt
+copybutton_prompt_text = r'>>> |\.\.\. '
+copybutton_prompt_is_regexp = True
+
 # If true, add an index to the HTML documents.
 html_use_index = False
 
@@ -378,7 +402,7 @@ latex_paper_size = 'letter'
 #    document class [howto/manual])
 
 latex_documents = [
-    ('contents', 'Matplotlib.tex', 'Matplotlib',
+    (root_doc, 'Matplotlib.tex', 'Matplotlib',
      'John Hunter\\and Darren Dale\\and Eric Firing\\and Michael Droettboom'
      '\\and and the matplotlib development team', 'manual'),
 ]
@@ -461,6 +485,8 @@ latex_elements['passoptionstopackages'] = r"""
 
 # Additional stuff for the LaTeX preamble.
 latex_elements['preamble'] = r"""
+   % Show Parts and Chapters in Table of Contents
+   \setcounter{tocdepth}{0}
    % One line per author on title page
    \DeclareRobustCommand{\and}%
      {\end{tabular}\kern-\tabcolsep\\\begin{tabular}[t]{c}}%
@@ -508,7 +534,7 @@ latex_toplevel_sectioning = 'part'
 autoclass_content = 'both'
 
 texinfo_documents = [
-    ("contents", 'matplotlib', 'Matplotlib Documentation',
+    (root_doc, 'matplotlib', 'Matplotlib Documentation',
      'John Hunter@*Darren Dale@*Eric Firing@*Michael Droettboom@*'
      'The matplotlib development team',
      'Matplotlib', "Python plotting package", 'Programming',
@@ -586,6 +612,8 @@ if link_github:
             except AttributeError:
                 return None
 
+        if inspect.isfunction(obj):
+            obj = inspect.unwrap(obj)
         try:
             fn = inspect.getsourcefile(obj)
         except TypeError:
