@@ -7,10 +7,11 @@ import matplotlib.colors as mcolors
 from matplotlib import rc_context
 from matplotlib.testing.decorators import image_comparison
 import matplotlib.pyplot as plt
-from matplotlib.colors import BoundaryNorm, LogNorm, PowerNorm, Normalize
+from matplotlib.colors import (
+    BoundaryNorm, LogNorm, PowerNorm, Normalize, NoNorm
+)
 from matplotlib.colorbar import Colorbar
 from matplotlib.ticker import FixedLocator
-
 from matplotlib.testing.decorators import check_figures_equal
 
 
@@ -123,6 +124,30 @@ def test_colorbar_extension_length():
     _colorbar_extension_length('proportional')
 
 
+@pytest.mark.parametrize("orientation", ["horizontal", "vertical"])
+@pytest.mark.parametrize("extend,expected", [("min", (0, 0, 0, 1)),
+                                             ("max", (1, 1, 1, 1)),
+                                             ("both", (1, 1, 1, 1))])
+def test_colorbar_extension_inverted_axis(orientation, extend, expected):
+    """Test extension color with an inverted axis"""
+    data = np.arange(12).reshape(3, 4)
+    fig, ax = plt.subplots()
+    cmap = plt.get_cmap("viridis").with_extremes(under=(0, 0, 0, 1),
+                                                 over=(1, 1, 1, 1))
+    im = ax.imshow(data, cmap=cmap)
+    cbar = fig.colorbar(im, orientation=orientation, extend=extend)
+    if orientation == "horizontal":
+        cbar.ax.invert_xaxis()
+    else:
+        cbar.ax.invert_yaxis()
+    assert cbar._extend_patches[0].get_facecolor() == expected
+    if extend == "both":
+        assert len(cbar._extend_patches) == 2
+        assert cbar._extend_patches[1].get_facecolor() == (0, 0, 0, 1)
+    else:
+        assert len(cbar._extend_patches) == 1
+
+
 @pytest.mark.parametrize('use_gridspec', [True, False])
 @image_comparison(['cbar_with_orientation',
                    'cbar_locationing',
@@ -185,6 +210,37 @@ def test_colorbar_positioning(use_gridspec):
                  anchor=(0.8, 0.5), shrink=0.6, use_gridspec=use_gridspec)
 
 
+def test_colorbar_single_ax_panchor_false():
+    # Note that this differs from the tests above with panchor=False because
+    # there use_gridspec is actually ineffective: passing *ax* as lists always
+    # disables use_gridspec.
+    ax = plt.subplot(111, anchor='N')
+    plt.imshow([[0, 1]])
+    plt.colorbar(panchor=False)
+    assert ax.get_anchor() == 'N'
+
+
+@pytest.mark.parametrize('constrained', [False, True],
+                         ids=['standard', 'constrained'])
+def test_colorbar_single_ax_panchor_east(constrained):
+    fig = plt.figure(constrained_layout=constrained)
+    ax = fig.add_subplot(111, anchor='N')
+    plt.imshow([[0, 1]])
+    plt.colorbar(panchor='E')
+    assert ax.get_anchor() == 'E'
+
+
+@image_comparison(['contour_colorbar.png'], remove_text=True)
+def test_contour_colorbar():
+    fig, ax = plt.subplots(figsize=(4, 2))
+    data = np.arange(1200).reshape(30, 40) - 500
+    levels = np.array([0, 200, 400, 600, 800, 1000, 1200]) - 500
+
+    CS = ax.contour(data, levels=levels, extend='both')
+    fig.colorbar(CS, orientation='horizontal', extend='both')
+    fig.colorbar(CS, orientation='vertical')
+
+
 @image_comparison(['cbar_with_subplots_adjust.png'], remove_text=True,
                   savefig_kwarg={'dpi': 40})
 def test_gridspec_make_colorbar():
@@ -871,3 +927,130 @@ def test_proportional_colorbars():
             CS3 = axs[i, j].contourf(X, Y, Z, levels, cmap=cmap, norm=norm,
                                      extend=extends[i])
             fig.colorbar(CS3, spacing=spacings[j], ax=axs[i, j])
+
+
+@image_comparison(['extend_drawedges.png'], remove_text=True, style='mpl20')
+def test_colorbar_extend_drawedges():
+    params = [
+        ('both', 1, [[[1.1, 0], [1.1, 1]],
+                     [[2, 0], [2, 1]],
+                     [[2.9, 0], [2.9, 1]]]),
+        ('min', 0, [[[1.1, 0], [1.1, 1]],
+                    [[2, 0], [2, 1]]]),
+        ('max', 0, [[[2, 0], [2, 1]],
+                    [[2.9, 0], [2.9, 1]]]),
+        ('neither', -1, [[[2, 0], [2, 1]]]),
+    ]
+
+    plt.rcParams['axes.linewidth'] = 2
+
+    fig = plt.figure(figsize=(10, 4))
+    subfigs = fig.subfigures(1, 2)
+
+    for orientation, subfig in zip(['horizontal', 'vertical'], subfigs):
+        if orientation == 'horizontal':
+            axs = subfig.subplots(4, 1)
+        else:
+            axs = subfig.subplots(1, 4)
+        fig.subplots_adjust(left=0.05, bottom=0.05, right=0.95, top=0.95)
+
+        for ax, (extend, coloroffset, res) in zip(axs, params):
+            cmap = plt.get_cmap("viridis")
+            bounds = np.arange(5)
+            nb_colors = len(bounds) + coloroffset
+            colors = cmap(np.linspace(100, 255, nb_colors).astype(int))
+            cmap, norm = mcolors.from_levels_and_colors(bounds, colors,
+                                                        extend=extend)
+
+            cbar = Colorbar(ax, cmap=cmap, norm=norm, orientation=orientation,
+                            drawedges=True)
+            # Set limits such that only two colours are visible, and the
+            # dividers would be outside the Axes, to ensure that a) they are
+            # not drawn outside, and b) a divider still appears between the
+            # main colour and the extension.
+            if orientation == 'horizontal':
+                ax.set_xlim(1.1, 2.9)
+            else:
+                ax.set_ylim(1.1, 2.9)
+                res = np.array(res)[:, :, [1, 0]]
+            np.testing.assert_array_equal(cbar.dividers.get_segments(), res)
+
+
+def test_negative_boundarynorm():
+    fig, ax = plt.subplots(figsize=(1, 3))
+    cmap = plt.get_cmap("viridis")
+
+    clevs = np.arange(-94, -85)
+    norm = BoundaryNorm(clevs, cmap.N)
+    cb = fig.colorbar(cm.ScalarMappable(cmap=cmap, norm=norm), cax=ax)
+    np.testing.assert_allclose(cb.ax.get_ylim(), [clevs[0], clevs[-1]])
+    np.testing.assert_allclose(cb.ax.get_yticks(), clevs)
+
+    clevs = np.arange(85, 94)
+    norm = BoundaryNorm(clevs, cmap.N)
+    cb = fig.colorbar(cm.ScalarMappable(cmap=cmap, norm=norm), cax=ax)
+    np.testing.assert_allclose(cb.ax.get_ylim(), [clevs[0], clevs[-1]])
+    np.testing.assert_allclose(cb.ax.get_yticks(), clevs)
+
+    clevs = np.arange(-3, 3)
+    norm = BoundaryNorm(clevs, cmap.N)
+    cb = fig.colorbar(cm.ScalarMappable(cmap=cmap, norm=norm), cax=ax)
+    np.testing.assert_allclose(cb.ax.get_ylim(), [clevs[0], clevs[-1]])
+    np.testing.assert_allclose(cb.ax.get_yticks(), clevs)
+
+    clevs = np.arange(-8, 1)
+    norm = BoundaryNorm(clevs, cmap.N)
+    cb = fig.colorbar(cm.ScalarMappable(cmap=cmap, norm=norm), cax=ax)
+    np.testing.assert_allclose(cb.ax.get_ylim(), [clevs[0], clevs[-1]])
+    np.testing.assert_allclose(cb.ax.get_yticks(), clevs)
+
+
+@image_comparison(['nonorm_colorbars.svg'], remove_text=False,
+                  style='mpl20')
+def test_nonorm():
+    plt.rcParams['svg.fonttype'] = 'none'
+    data = [1, 2, 3, 4, 5]
+
+    fig, ax = plt.subplots(figsize=(6, 1))
+    fig.subplots_adjust(bottom=0.5)
+
+    norm = NoNorm(vmin=min(data), vmax=max(data))
+    cmap = cm.get_cmap("viridis", len(data))
+    mappable = cm.ScalarMappable(norm=norm, cmap=cmap)
+    cbar = fig.colorbar(mappable, cax=ax, orientation="horizontal")
+
+
+@image_comparison(['test_boundaries.png'], remove_text=True,
+                  style='mpl20')
+def test_boundaries():
+    np.random.seed(seed=19680808)
+    fig, ax = plt.subplots(figsize=(2, 2))
+    pc = ax.pcolormesh(np.random.randn(10, 10), cmap='RdBu_r')
+    cb = fig.colorbar(pc, ax=ax, boundaries=np.linspace(-3, 3, 7))
+
+
+def test_offset_text_loc():
+    plt.style.use('mpl20')
+    fig, ax = plt.subplots()
+    np.random.seed(seed=19680808)
+    pc = ax.pcolormesh(np.random.randn(10, 10)*1e6)
+    cb = fig.colorbar(pc, location='right', extend='max')
+    fig.draw_without_rendering()
+    # check that the offsetText is in the proper place above the
+    # colorbar axes.  In this case the colorbar axes is the same
+    # height as the parent, so use the parents bbox.
+    assert cb.ax.yaxis.offsetText.get_position()[1] > ax.bbox.y1
+
+
+def test_title_text_loc():
+    plt.style.use('mpl20')
+    fig, ax = plt.subplots()
+    np.random.seed(seed=19680808)
+    pc = ax.pcolormesh(np.random.randn(10, 10))
+    cb = fig.colorbar(pc, location='right', extend='max')
+    cb.ax.set_title('Aardvark')
+    fig.draw_without_rendering()
+    # check that the title is in the proper place above the
+    # colorbar axes, including its extend triangles....
+    assert (cb.ax.title.get_window_extent(fig.canvas.get_renderer()).ymax >
+            cb.ax.spines['outline'].get_window_extent().ymax)
