@@ -67,7 +67,8 @@ def quantity_converter():
             return None
 
     qc.convert = MagicMock(side_effect=convert)
-    qc.axisinfo = MagicMock(side_effect=lambda u, a: munits.AxisInfo(label=u))
+    qc.axisinfo = MagicMock(side_effect=lambda u, a:
+                            munits.AxisInfo(label=u, default_limits=(0, 100)))
     qc.default_units = MagicMock(side_effect=default_units)
     return qc
 
@@ -166,6 +167,14 @@ def test_scatter_element0_masked():
     fig.canvas.draw()
 
 
+def test_errorbar_mixed_units():
+    x = np.arange(10)
+    y = [datetime(2020, 5, i * 2 + 1) for i in x]
+    fig, ax = plt.subplots()
+    ax.errorbar(x, y, timedelta(days=0.5))
+    fig.canvas.draw()
+
+
 @check_figures_equal(extensions=["png"])
 def test_subclass(fig_test, fig_ref):
     class subdate(datetime):
@@ -211,3 +220,63 @@ def test_shared_axis_categorical():
     ax2.plot(d2.keys(), d2.values())
     ax1.xaxis.set_units(UnitData(["c", "d"]))
     assert "c" in ax2.xaxis.get_units()._mapping.keys()
+
+
+def test_empty_default_limits(quantity_converter):
+    munits.registry[Quantity] = quantity_converter
+    fig, ax1 = plt.subplots()
+    ax1.xaxis.update_units(Quantity([10], "miles"))
+    fig.draw_without_rendering()
+    assert ax1.get_xlim() == (0, 100)
+    ax1.yaxis.update_units(Quantity([10], "miles"))
+    fig.draw_without_rendering()
+    assert ax1.get_ylim() == (0, 100)
+
+    fig, ax = plt.subplots()
+    ax.axhline(30)
+    ax.plot(Quantity(np.arange(0, 3), "miles"),
+            Quantity(np.arange(0, 6, 2), "feet"))
+    fig.draw_without_rendering()
+    assert ax.get_xlim() == (0, 2)
+    assert ax.get_ylim() == (0, 30)
+
+    fig, ax = plt.subplots()
+    ax.axvline(30)
+    ax.plot(Quantity(np.arange(0, 3), "miles"),
+            Quantity(np.arange(0, 6, 2), "feet"))
+    fig.draw_without_rendering()
+    assert ax.get_xlim() == (0, 30)
+    assert ax.get_ylim() == (0, 4)
+
+    fig, ax = plt.subplots()
+    ax.xaxis.update_units(Quantity([10], "miles"))
+    ax.axhline(30)
+    fig.draw_without_rendering()
+    assert ax.get_xlim() == (0, 100)
+    assert ax.get_ylim() == (28.5, 31.5)
+
+    fig, ax = plt.subplots()
+    ax.yaxis.update_units(Quantity([10], "miles"))
+    ax.axvline(30)
+    fig.draw_without_rendering()
+    assert ax.get_ylim() == (0, 100)
+    assert ax.get_xlim() == (28.5, 31.5)
+
+
+# test array-like objects...
+class Kernel:
+    def __init__(self, array):
+        self._array = np.asanyarray(array)
+
+    def __array__(self):
+        return self._array
+
+    @property
+    def shape(self):
+        return self._array.shape
+
+
+def test_plot_kernel():
+    # just a smoketest that fail
+    kernel = Kernel([1, 2, 3, 4, 5])
+    plt.plot(kernel)
