@@ -2,7 +2,6 @@
 Classes for including text in a figure.
 """
 
-import contextlib
 import logging
 import math
 import weakref
@@ -22,20 +21,6 @@ from .transforms import (
 _log = logging.getLogger(__name__)
 
 
-@contextlib.contextmanager
-def _wrap_text(textobj):
-    """Temporarily inserts newlines if the wrap option is enabled."""
-    if textobj.get_wrap():
-        old_text = textobj.get_text()
-        try:
-            textobj.set_text(textobj._get_wrapped_text())
-            yield textobj
-        finally:
-            textobj.set_text(old_text)
-    else:
-        yield textobj
-
-
 # Extracted from Text's method to serve as a function
 def get_rotation(rotation):
     """
@@ -103,6 +88,7 @@ def _get_textbox(text, renderer):
     return x_box, y_box, w_box, h_box
 
 
+@docstring.interpd
 @cbook._define_aliases({
     "color": ["c"],
     "fontfamily": ["family"],
@@ -139,6 +125,8 @@ class Text(Artist):
                  usetex=None,          # defaults to rcParams['text.usetex']
                  wrap=False,
                  transform_rotates_text=False,
+                 *,
+                 parse_math=True,
                  **kwargs
                  ):
         """
@@ -146,7 +134,7 @@ class Text(Artist):
 
         Valid keyword arguments are:
 
-        %(Text_kwdoc)s
+        %(Text:kwdoc)s
         """
         super().__init__()
         self._x, self._y = x, y
@@ -156,6 +144,7 @@ class Text(Artist):
             color if color is not None else mpl.rcParams["text.color"])
         self.set_fontproperties(fontproperties)
         self.set_usetex(usetex)
+        self.set_parse_math(parse_math)
         self.set_wrap(wrap)
         self.set_verticalalignment(verticalalignment)
         self.set_horizontalalignment(horizontalalignment)
@@ -172,8 +161,7 @@ class Text(Artist):
 
     def update(self, kwargs):
         # docstring inherited
-        # make a copy so we do not mutate user input!
-        kwargs = dict(kwargs)
+        kwargs = cbook.normalize_kwargs(kwargs, Text)
         sentinel = object()  # bbox can be None, so use another sentinel.
         # Update fontproperties first, as it has lowest priority.
         fontproperties = kwargs.pop("fontproperties", sentinel)
@@ -284,13 +272,28 @@ class Text(Artist):
         self._linespacing = other._linespacing
         self.stale = True
 
+    def _get_layout_cache_key(self, renderer=None):
+        """
+        Return a hashable tuple of properties that lets `_get_layout` know
+        whether a previously computed layout can be reused.
+        """
+        x, y = self.get_unitless_position()
+        renderer = renderer or self._renderer
+        return (
+            x, y, self.get_text(), hash(self._fontproperties),
+            self._verticalalignment, self._horizontalalignment,
+            self._linespacing,
+            self._rotation, self._rotation_mode, self._transform_rotates_text,
+            self.figure.dpi, weakref.ref(renderer),
+        )
+
     def _get_layout(self, renderer):
         """
         Return the extent (bbox) of the text together with
         multiple-alignment information. Note that it returns an extent
         of a rotated text when necessary.
         """
-        key = self.get_prop_tup(renderer=renderer)
+        key = self._get_layout_cache_key(renderer=renderer)
         if key in self._cached:
             return self._cached[key]
 
@@ -616,9 +619,12 @@ class Text(Artist):
 
     def _get_wrapped_text(self):
         """
-        Return a copy of the text with new lines added, so that
-        the text is wrapped relative to the parent figure.
+        Return a copy of the text string with new lines added so that the text
+        is wrapped relative to the parent figure (if `get_wrap` is True).
         """
+        if not self.get_wrap():
+            return self.get_text()
+
         # Not fit to handle breaking up latex syntax correctly, so
         # ignore latex for now.
         if self.get_usetex():
@@ -675,14 +681,14 @@ class Text(Artist):
 
         renderer.open_group('text', self.get_gid())
 
-        with _wrap_text(self) as textobj:
-            bbox, info, descent = textobj._get_layout(renderer)
-            trans = textobj.get_transform()
+        with self._cm_set(text=self._get_wrapped_text()):
+            bbox, info, descent = self._get_layout(renderer)
+            trans = self.get_transform()
 
-            # don't use textobj.get_position here, which refers to text
+            # don't use self.get_position here, which refers to text
             # position in Text:
-            posx = float(textobj.convert_xunits(textobj._x))
-            posy = float(textobj.convert_yunits(textobj._y))
+            posx = float(self.convert_xunits(self._x))
+            posy = float(self.convert_yunits(self._y))
             posx, posy = trans.transform((posx, posy))
             if not np.isfinite(posx) or not np.isfinite(posy):
                 _log.warning("posx and posy should be finite values")
@@ -691,41 +697,41 @@ class Text(Artist):
 
             # Update the location and size of the bbox
             # (`.patches.FancyBboxPatch`), and draw it.
-            if textobj._bbox_patch:
+            if self._bbox_patch:
                 self.update_bbox_position_size(renderer)
                 self._bbox_patch.draw(renderer)
 
             gc = renderer.new_gc()
-            gc.set_foreground(textobj.get_color())
-            gc.set_alpha(textobj.get_alpha())
-            gc.set_url(textobj._url)
-            textobj._set_gc_clip(gc)
+            gc.set_foreground(self.get_color())
+            gc.set_alpha(self.get_alpha())
+            gc.set_url(self._url)
+            self._set_gc_clip(gc)
 
-            angle = textobj.get_rotation()
+            angle = self.get_rotation()
 
             for line, wh, x, y in info:
 
-                mtext = textobj if len(info) == 1 else None
+                mtext = self if len(info) == 1 else None
                 x = x + posx
                 y = y + posy
                 if renderer.flipy():
                     y = canvash - y
-                clean_line, ismath = textobj._preprocess_math(line)
+                clean_line, ismath = self._preprocess_math(line)
 
-                if textobj.get_path_effects():
+                if self.get_path_effects():
                     from matplotlib.patheffects import PathEffectRenderer
                     textrenderer = PathEffectRenderer(
-                        textobj.get_path_effects(), renderer)
+                        self.get_path_effects(), renderer)
                 else:
                     textrenderer = renderer
 
-                if textobj.get_usetex():
+                if self.get_usetex():
                     textrenderer.draw_tex(gc, x, y, clean_line,
-                                          textobj._fontproperties, angle,
+                                          self._fontproperties, angle,
                                           mtext=mtext)
                 else:
                     textrenderer.draw_text(gc, x, y, clean_line,
-                                           textobj._fontproperties, angle,
+                                           self._fontproperties, angle,
                                            ismath=ismath, mtext=mtext)
 
         gc.restore()
@@ -831,6 +837,8 @@ class Text(Artist):
         # specified with 'set_x' and 'set_y'.
         return self._x, self._y
 
+    # When removing, also remove the hash(color) check in set_color()
+    @_api.deprecated("3.5")
     def get_prop_tup(self, renderer=None):
         """
         Return a hashable tuple of properties.
@@ -882,7 +890,6 @@ class Text(Artist):
             ``self.figure.dpi`` (*not* the renderer dpi); should be set e.g. if
             to match regions with a figure saved with a custom dpi value.
         """
-        #return _unit_box
         if not self.get_visible():
             return Bbox.unit()
         if dpi is None:
@@ -938,7 +945,8 @@ class Text(Artist):
         # out at draw time for simplicity.
         if not cbook._str_equal(color, "auto"):
             mpl.colors._check_color_like(color=color)
-        # Make sure it is hashable, or get_prop_tup will fail.
+        # Make sure it is hashable, or get_prop_tup will fail (remove this once
+        # get_prop_tup is removed).
         try:
             hash(color)
         except TypeError:
@@ -1224,7 +1232,8 @@ class Text(Artist):
         - If *self* is configured to use TeX, return *s* unchanged except that
           a single space gets escaped, and the flag "TeX".
         - Otherwise, if *s* is mathtext (has an even number of unescaped dollar
-          signs), return *s* and the flag True.
+          signs) and ``parse_math`` is not set to False, return *s* and the
+          flag True.
         - Otherwise, return *s* with dollar signs unescaped, and the flag
           False.
         """
@@ -1232,6 +1241,8 @@ class Text(Artist):
             if s == " ":
                 s = r"\ "
             return s, "TeX"
+        elif not self.get_parse_math():
+            return s, False
         elif cbook.is_math_text(s):
             return s, True
         else:
@@ -1269,6 +1280,22 @@ class Text(Artist):
         """Return whether this `Text` object uses TeX for rendering."""
         return self._usetex
 
+    def set_parse_math(self, parse_math):
+        """
+        Override switch to disable any mathtext parsing for this `Text`.
+
+        Parameters
+        ----------
+        parse_math : bool
+            If False, this `Text` will never use mathtext.  If True, mathtext
+            will be used if there is an even number of unescaped dollar signs.
+        """
+        self._parse_math = bool(parse_math)
+
+    def get_parse_math(self):
+        """Return whether mathtext parsing is considered for this `Text`."""
+        return self._parse_math
+
     def set_fontname(self, fontname):
         """
         Alias for `set_family`.
@@ -1288,10 +1315,6 @@ class Text(Artist):
         return self.set_family(fontname)
 
 
-docstring.interpd.update(Text_kwdoc=artist.kwdoc(Text))
-docstring.dedent_interpd(Text.__init__)
-
-
 class OffsetFrom:
     """Callable helper class for working with `Annotation`."""
 
@@ -1463,13 +1486,13 @@ class _AnnotationBase:
             ref_x, ref_y = xy0
             if unit == "points":
                 # dots per points
-                dpp = self.figure.get_dpi() / 72.
+                dpp = self.figure.dpi / 72
                 tr = Affine2D().scale(dpp)
             elif unit == "pixels":
                 tr = Affine2D()
             elif unit == "fontsize":
                 fontsize = self.get_size()
-                dpp = fontsize * self.figure.get_dpi() / 72.
+                dpp = fontsize * self.figure.dpi / 72
                 tr = Affine2D().scale(dpp)
             elif unit == "fraction":
                 w, h = bbox0.size
@@ -1687,9 +1710,13 @@ class Annotation(Text, _AnnotationBase):
 
         arrowprops : dict, optional
             The properties used to draw a `.FancyArrowPatch` arrow between the
-            positions *xy* and *xytext*. Note that the edge of the arrow
-            pointing to *xytext* will be centered on the text itself and may
-            not point directly to the coordinates given in *xytext*.
+            positions *xy* and *xytext*.  Defaults to None, i.e. no arrow is
+            drawn.
+
+            For historical reasons there are two different ways to specify
+            arrows, "simple" and "fancy":
+
+            **Simple arrow:**
 
             If *arrowprops* does not contain the key 'arrowstyle' the
             allowed keys are:
@@ -1704,35 +1731,22 @@ class Annotation(Text, _AnnotationBase):
             ?            Any key to :class:`matplotlib.patches.FancyArrowPatch`
             ==========   ======================================================
 
-            If *arrowprops* contains the key 'arrowstyle' the
-            above keys are forbidden.  The allowed values of
-            ``'arrowstyle'`` are:
+            The arrow is attached to the edge of the text box, the exact
+            position (corners or centers) depending on where it's pointing to.
 
-            ============   =============================================
-            Name           Attrs
-            ============   =============================================
-            ``'-'``        None
-            ``'->'``       head_length=0.4,head_width=0.2
-            ``'-['``       widthB=1.0,lengthB=0.2,angleB=None
-            ``'|-|'``      widthA=1.0,widthB=1.0
-            ``'-|>'``      head_length=0.4,head_width=0.2
-            ``'<-'``       head_length=0.4,head_width=0.2
-            ``'<->'``      head_length=0.4,head_width=0.2
-            ``'<|-'``      head_length=0.4,head_width=0.2
-            ``'<|-|>'``    head_length=0.4,head_width=0.2
-            ``'fancy'``    head_length=0.4,head_width=0.4,tail_width=0.4
-            ``'simple'``   head_length=0.5,head_width=0.5,tail_width=0.2
-            ``'wedge'``    tail_width=0.3,shrink_factor=0.5
-            ============   =============================================
+            **Fancy arrow:**
 
-            Valid keys for `~matplotlib.patches.FancyArrowPatch` are:
+            This is used if 'arrowstyle' is provided in the *arrowprops*.
+
+            Valid keys are the following `~matplotlib.patches.FancyArrowPatch`
+            parameters:
 
             ===============  ==================================================
             Key              Description
             ===============  ==================================================
             arrowstyle       the arrow style
             connectionstyle  the connection style
-            relpos           default is (0.5, 0.5)
+            relpos           see below; default is (0.5, 0.5)
             patchA           default is bounding box of the text
             patchB           default is None
             shrinkA          default is 2 points
@@ -1742,7 +1756,12 @@ class Annotation(Text, _AnnotationBase):
             ?                any key for :class:`matplotlib.patches.PathPatch`
             ===============  ==================================================
 
-            Defaults to None, i.e. no arrow is drawn.
+            The exact starting point position of the arrow is defined by
+            *relpos*. It's a tuple of relative coordinates of the text box,
+            where (0, 0) is the lower left corner and (1, 1) is the upper
+            right corner. Values <0 and >1 are supported and specify points
+            outside the text box. By default (0.5, 0.5) the starting point is
+            centered in the text box.
 
         annotation_clip : bool or None, default: None
             Whether to draw the annotation when the annotation point *xy* is
@@ -1962,18 +1981,7 @@ class Annotation(Text, _AnnotationBase):
         Text.draw(self, renderer)
 
     def get_window_extent(self, renderer=None):
-        """
-        Return the `.Bbox` bounding the text and arrow, in display units.
-
-        Parameters
-        ----------
-        renderer : Renderer, optional
-            A renderer is needed to compute the bounding box.  If the artist
-            has already been drawn, the renderer is cached; thus, it is only
-            necessary to pass this argument when calling `get_window_extent`
-            before the first `draw`.  In practice, it is usually easier to
-            trigger a draw first (e.g. by saving the figure).
-        """
+        # docstring inherited
         # This block is the same as in Text.get_window_extent, but we need to
         # set the renderer before calling update_positions().
         if not self.get_visible() or not self._check_xy(renderer):
