@@ -16,7 +16,7 @@ or PDF, what you see on the screen is what you get in the hardcopy.
 produces very nice, antialiased fonts, that look good even at small
 raster sizes.  Matplotlib includes its own
 :mod:`matplotlib.font_manager` (thanks to Paul Barrett), which
-implements a cross platform, `W3C <http://www.w3.org/>`
+implements a cross platform, `W3C <https://www.w3.org/>`_
 compliant font finding algorithm.
 
 The user has a great deal of control over text properties (font size, font
@@ -69,15 +69,19 @@ import matplotlib
 import matplotlib.pyplot as plt
 
 fig = plt.figure()
-fig.suptitle('bold figure suptitle', fontsize=14, fontweight='bold')
-
-ax = fig.add_subplot(111)
+ax = fig.add_subplot()
 fig.subplots_adjust(top=0.85)
+
+# Set titles for the figure and the subplot respectively
+fig.suptitle('bold figure suptitle', fontsize=14, fontweight='bold')
 ax.set_title('axes title')
 
 ax.set_xlabel('xlabel')
 ax.set_ylabel('ylabel')
 
+# Set both x- and y-axis limits to [0, 10] instead of default [0, 1]
+ax.axis([0, 10, 0, 10])
+
 ax.text(3, 8, 'boxed italics text in data coords', style='italic',
         bbox={'facecolor': 'red', 'alpha': 0.5, 'pad': 10})
 
@@ -90,13 +94,10 @@ ax.text(0.95, 0.01, 'colored text in axes coords',
         transform=ax.transAxes,
         color='green', fontsize=15)
 
-
 ax.plot([2], [1], 'o')
 ax.annotate('annotate', xy=(2, 1), xytext=(3, 4),
             arrowprops=dict(facecolor='black', shrink=0.05))
 
-ax.axis([0, 10, 0, 10])
-
 plt.show()
 
 ###############################################################################
@@ -152,21 +153,20 @@ plt.show()
 # *position*, via which we can manually specify the label positions.  Here we
 # put the xlabel to the far left of the axis.  Note, that the y-coordinate of
 # this position has no effect - to adjust the y-position we need to use the
-# *labelpad* kwarg.
+# *labelpad* keyword argument.
 
 fig, ax = plt.subplots(figsize=(5, 3))
 fig.subplots_adjust(bottom=0.15, left=0.2)
 ax.plot(x1, y1)
-ax.set_xlabel('time [s]', position=(0., 1e6),
-                      horizontalalignment='left')
+ax.set_xlabel('time [s]', position=(0., 1e6), horizontalalignment='left')
 ax.set_ylabel('Damped oscillation [V]')
 
 plt.show()
 
 ##############################################################################
 # All the labelling in this tutorial can be changed by manipulating the
-# `matplotlib.font_manager.FontProperties` method, or by named kwargs to
-# `~matplotlib.axes.Axes.set_xlabel`
+# `matplotlib.font_manager.FontProperties` method, or by named keyword
+# arguments to `~matplotlib.axes.Axes.set_xlabel`
 
 from matplotlib.font_manager import FontProperties
 
@@ -211,8 +211,8 @@ for ax, loc in zip(axs, locs):
 plt.show()
 
 ##############################################################################
-# Vertical spacing for titles is controlled via :rc:`axes.titlepad`, which
-# defaults to 5 points.  Setting to a different value moves the title.
+# Vertical spacing for titles is controlled via :rc:`axes.titlepad`.
+# Setting to a different value moves the title.
 
 fig, ax = plt.subplots(figsize=(5, 3))
 fig.subplots_adjust(top=0.8)
@@ -226,34 +226,32 @@ plt.show()
 # ====================
 #
 # Placing ticks and ticklabels is a very tricky aspect of making a figure.
-# Matplotlib does the best it can automatically, but it also offers a very
-# flexible framework for determining the choices for tick locations, and
-# how they are labelled.
+# Matplotlib does its best to accomplish the task automatically, but it also
+# offers a very flexible framework for determining the choices for tick
+# locations, and how they are labelled.
 #
 # Terminology
 # ~~~~~~~~~~~
 #
-# *Axes* have an `matplotlib.axis` object for the ``ax.xaxis``
-# and ``ax.yaxis`` that
-# contain the information about how the labels in the axis are laid out.
+# *Axes* have an `matplotlib.axis.Axis` object for the ``ax.xaxis`` and
+# ``ax.yaxis`` that contain the information about how the labels in the axis
+# are laid out.
 #
 # The axis API is explained in detail in the documentation to
 # `~matplotlib.axis`.
 #
-# An Axis object has major and minor ticks.  The Axis has a
-# `matplotlib.xaxis.set_major_locator` and
-# `matplotlib.xaxis.set_minor_locator` methods that use the data being plotted
-# to determine
-# the location of major and minor ticks.  There are also
-# `matplotlib.xaxis.set_major_formatter` and
-# `matplotlib.xaxis.set_minor_formatters` methods that format the tick labels.
+# An Axis object has major and minor ticks.  The Axis has
+# `.Axis.set_major_locator` and `.Axis.set_minor_locator` methods that use the
+# data being plotted to determine the location of major and minor ticks.  There
+# are also `.Axis.set_major_formatter` and `.Axis.set_minor_formatter` methods
+# that format the tick labels.
 #
 # Simple ticks
 # ~~~~~~~~~~~~
 #
 # It often is convenient to simply define the
 # tick values, and sometimes the tick labels, overriding the default
-# locators and formatters.  This is discouraged because it breaks itneractive
+# locators and formatters.  This is discouraged because it breaks interactive
 # navigation of the plot.  It also can reset the axis limits: note that
 # the second plot has the ticks we asked for, including ones that are
 # well outside the automatic view limits.
@@ -274,7 +272,7 @@ axs[0].plot(x1, y1)
 axs[1].plot(x1, y1)
 ticks = np.arange(0., 8.1, 2.)
 # list comprehension to get all tick labels...
-tickla = ['%1.2f' % tick for tick in ticks]
+tickla = [f'{tick:1.2f}' for tick in ticks]
 axs[1].xaxis.set_ticks(ticks)
 axs[1].xaxis.set_ticklabels(tickla)
 axs[1].set_xlim(axs[0].get_xlim())
@@ -285,17 +283,18 @@ plt.show()
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 #
 # Instead of making a list of all the tickalbels, we could have
-# used a `matplotlib.ticker.FormatStrFormatter` and passed it to the
-# ``ax.xaxis``
+# used `matplotlib.ticker.StrMethodFormatter` (new-style ``str.format()``
+# format string) or `matplotlib.ticker.FormatStrFormatter` (old-style '%'
+# format string) and passed it to the ``ax.xaxis``.  A
+# `matplotlib.ticker.StrMethodFormatter` can also be created by passing a
+# ``str`` without having to explicitly create the formatter.
 
 fig, axs = plt.subplots(2, 1, figsize=(5, 3), tight_layout=True)
 axs[0].plot(x1, y1)
 axs[1].plot(x1, y1)
 ticks = np.arange(0., 8.1, 2.)
-# list comprehension to get all tick labels...
-formatter = matplotlib.ticker.StrMethodFormatter('{x:1.1f}')
 axs[1].xaxis.set_ticks(ticks)
-axs[1].xaxis.set_major_formatter(formatter)
+axs[1].xaxis.set_major_formatter('{x:1.1f}')
 axs[1].set_xlim(axs[0].get_xlim())
 plt.show()
 
@@ -307,10 +306,9 @@ plt.show()
 fig, axs = plt.subplots(2, 1, figsize=(5, 3), tight_layout=True)
 axs[0].plot(x1, y1)
 axs[1].plot(x1, y1)
-formatter = matplotlib.ticker.FormatStrFormatter('%1.1f')
 locator = matplotlib.ticker.FixedLocator(ticks)
 axs[1].xaxis.set_major_locator(locator)
-axs[1].xaxis.set_major_formatter(formatter)
+axs[1].xaxis.set_major_formatter('±{x}°')
 plt.show()
 
 #############################################################################
@@ -351,26 +349,28 @@ plt.show()
 
 ##############################################################################
 #  Finally, we can specify functions for the formatter using
-# `matplotlib.ticker.FuncFormatter`.
+# `matplotlib.ticker.FuncFormatter`.  Further, like
+# `matplotlib.ticker.StrMethodFormatter`, passing a function will
+# automatically create a `matplotlib.ticker.FuncFormatter`.
 
 
 def formatoddticks(x, pos):
-    """Format odd tick positions
-    """
+    """Format odd tick positions."""
     if x % 2:
-        return '%1.2f' % x
+        return f'{x:1.2f}'
     else:
         return ''
 
+
 fig, ax = plt.subplots(figsize=(5, 3), tight_layout=True)
 ax.plot(x1, y1)
-formatter = matplotlib.ticker.FuncFormatter(formatoddticks)
 locator = matplotlib.ticker.MaxNLocator(nbins=6)
-ax.xaxis.set_major_formatter(formatter)
+ax.xaxis.set_major_formatter(formatoddticks)
 ax.xaxis.set_major_locator(locator)
 
 plt.show()
 
+
 ##############################################################################
 # Dateticks
 # ~~~~~~~~~
@@ -383,23 +383,23 @@ plt.show()
 #
 # A simple example is as follows.  Note how we have to rotate the
 # tick labels so that they don't over-run each other.
+
 import datetime
 
 fig, ax = plt.subplots(figsize=(5, 3), tight_layout=True)
 base = datetime.datetime(2017, 1, 1, 0, 0, 1)
-time = [base + datetime.timedelta(days=x) for x in range(len(y1))]
+time = [base + datetime.timedelta(days=x) for x in range(len(x1))]
 
 ax.plot(time, y1)
 ax.tick_params(axis='x', rotation=70)
 plt.show()
 
-
 ##############################################################################
-# We can pass a format
-# to `matplotlib.dates.DateFormatter`.  Also note that the 29th and the
-# next month are very close together.  We can fix this by using the
-# `dates.DayLocator` class, which allows us to specify a list of days of the
-# month to use. Similar formatters are listed in the `matplotlib.dates` module.
+# We can pass a format to `matplotlib.dates.DateFormatter`.  Also note that the
+# 29th and the next month are very close together.  We can fix this by using
+# the `.dates.DayLocator` class, which allows us to specify a list of days of
+# the month to use. Similar formatters are listed in the `matplotlib.dates`
+# module.
 
 import matplotlib.dates as mdates
 
